"""pybind NgOCC module"""
from __future__ import annotations
import netgen.libngpy._NgOCC
import typing
import netgen.libngpy._meshing
import numpy
import os

__all__ = [
    "ApproxParamType",
    "ArcOfCircle",
    "Axes",
    "Axis",
    "BSplineCurve",
    "BezierCurve",
    "Box",
    "COMPOUND",
    "COMPSOLID",
    "Circle",
    "Compound",
    "Cone",
    "ConnectEdgesToWires",
    "Cylinder",
    "Dir",
    "DirectionalInterval",
    "EDGE",
    "Edge",
    "Ellipse",
    "FACE",
    "Face",
    "Fuse",
    "Geom2d_Curve",
    "Geom_Surface",
    "Glue",
    "HalfSpace",
    "ListOfShapes",
    "LoadOCCGeometry",
    "MakeFillet",
    "MakeThickSolid",
    "OCCException",
    "OCCGeometry",
    "Pipe",
    "PipeShell",
    "Pnt",
    "Prism",
    "Revolve",
    "SHAPE",
    "SHELL",
    "SOLID",
    "Segment",
    "ShapeContinuity",
    "Solid",
    "Sphere",
    "SplineApproximation",
    "SplineInterpolation",
    "SplineSurfaceApproximation",
    "SplineSurfaceInterpolation",
    "TestXCAF",
    "ThruSections",
    "TopAbs_ShapeEnum",
    "TopLoc_Location",
    "TopoDS_Shape",
    "VERTEX",
    "Vec",
    "Vertex",
    "WIRE",
    "Wire",
    "WorkPlane",
    "X",
    "Y",
    "Z",
    "gp_Ax2",
    "gp_Ax2d",
    "gp_Dir",
    "gp_Dir2d",
    "gp_GTrsf",
    "gp_Pnt",
    "gp_Pnt2d",
    "gp_Trsf",
    "gp_Vec",
    "gp_Vec2d",
    "occ_version"
]


class ApproxParamType():
    """
    Wrapper for Approx_ParametrizationType

    Members:

      Centripetal

      ChordLength

      IsoParametric
    """
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self, value: int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self, state: int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> str:
        """
        :type: str
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    Centripetal: netgen.libngpy._NgOCC.ApproxParamType # value = <ApproxParamType.Centripetal: 1>
    ChordLength: netgen.libngpy._NgOCC.ApproxParamType # value = <ApproxParamType.ChordLength: 0>
    IsoParametric: netgen.libngpy._NgOCC.ApproxParamType # value = <ApproxParamType.IsoParametric: 2>
    __members__: dict # value = {'Centripetal': <ApproxParamType.Centripetal: 1>, 'ChordLength': <ApproxParamType.ChordLength: 0>, 'IsoParametric': <ApproxParamType.IsoParametric: 2>}
    pass
class Axes():
    """
    an OCC coordinate system in 3d
    """
    @typing.overload
    def __init__(self, arg0: gp_Ax2) -> None: ...
    @typing.overload
    def __init__(self, p: gp_Pnt = (0, 0, 0), n: gp_Dir = (0, 0, 1), h: gp_Dir = (1, 0, 0)) -> None: ...
    @property
    def p(self) -> gp_Pnt:
        """
        :type: gp_Pnt
        """
    @p.setter
    def p(self, arg1: gp_Pnt) -> None:
        pass
    pass
class Axis():
    """
    an OCC axis in 3d
    """
    def __init__(self, p: gp_Pnt, d: gp_Dir) -> None: ...
    pass
class TopoDS_Shape():
    def Distance(self, arg0: TopoDS_Shape) -> float: ...
    @typing.overload
    def Extrude(self, h: float, dir: typing.Optional[gp_Vec] = None) -> TopoDS_Shape: 
        """
        extrude shape to thickness 'h', shape must contain a plane surface, optionally give an extrusion direction

        extrude shape by vector 'v'
        """
    @typing.overload
    def Extrude(self, v: gp_Vec) -> TopoDS_Shape: ...
    def Identify(self, other: TopoDS_Shape, name: str, type: netgen.libngpy._meshing.IdentificationType = IdentificationType.PERIODIC, trafo: typing.Optional[typing.Union[gp_Trsf, gp_GTrsf]] = None) -> None: 
        """
        Identify shapes for periodic meshing
        """
    def Located(self, loc: TopLoc_Location) -> TopoDS_Shape: 
        """
        copy shape and sets location of copy
        """
    def MakeChamfer(self, edges: list[TopoDS_Shape], d: float) -> TopoDS_Shape: 
        """
        make symmetric chamfer for edges 'edges' of distrance 'd'
        """
    def MakeFillet(self, edges: list[TopoDS_Shape], r: float) -> TopoDS_Shape: 
        """
        make fillets for edges 'edges' of radius 'r'
        """
    def MakeThickSolid(self, facestoremove: list[TopoDS_Shape], offset: float, tol: float) -> TopoDS_Shape: 
        """
        makes shell-like solid from faces
        """
    def MakeTriangulation(self) -> None: ...
    @typing.overload
    def Mirror(self, axes: Axes) -> TopoDS_Shape: 
        """
        copy shape, and mirror over plane defined by 'axes'

        copy shape, and mirror around axis 'axis'
        """
    @typing.overload
    def Mirror(self, axes: Axis) -> TopoDS_Shape: ...
    def Move(self, v: gp_Vec) -> object: 
        """
        copy shape, and translate copy by vector 'v'
        """
    def Properties(self) -> tuple[object, object]: 
        """
        returns tuple of shape properties, currently ('mass', 'center'
        """
    def Reversed(self) -> object: ...
    def Revolve(self, axis: Axis, ang: float) -> TopoDS_Shape: 
        """
        revolve shape around 'axis' by 'ang' degrees
        """
    def Rotate(self, axis: Axis, ang: float) -> TopoDS_Shape: 
        """
        copy shape, and rotet copy by 'ang' degrees around 'axis'
        """
    def Scale(self, p: gp_Pnt, s: float) -> TopoDS_Shape: 
        """
        copy shape, and scale copy by factor 's'
        """
    def ShapeType(self) -> None: 
        """
        deprecated, use 'shape.type' instead
        """
    @staticmethod
    def SubShapes(*args, **kwargs) -> typing.Any: 
        """
        returns list of sub-shapes of type 'type'
        """
    @staticmethod
    def Triangulation(*args, **kwargs) -> typing.Any: ...
    def UnifySameDomain(self, unifyEdges: bool = True, unifyFaces: bool = True, concatBSplines: bool = True) -> TopoDS_Shape: ...
    def WriteStep(self, filename: str) -> None: 
        """
        export shape in STEP - format
        """
    def __add__(self, arg0: TopoDS_Shape) -> TopoDS_Shape: 
        """
        fuses shapes
        """
    def __eq__(self, arg0: TopoDS_Shape) -> bool: ...
    def __hash__(self) -> int: ...
    def __mul__(self, arg0: TopoDS_Shape) -> TopoDS_Shape: 
        """
        common of shapes
        """
    def __radd__(self, arg0: int) -> TopoDS_Shape: 
        """
        needed for Sum([shapes])
        """
    def __str__(self) -> str: ...
    def __sub__(self, arg0: TopoDS_Shape) -> TopoDS_Shape: 
        """
        cut of shapes
        """
    def _webgui_data(self) -> dict: ...
    def bc(self, name: str) -> TopoDS_Shape: 
        """
        sets 'name' property for all faces of shape
        """
    def mat(self, name: str) -> TopoDS_Shape: 
        """
        sets 'name' property to all solids of shape
        """
    @property
    def bounding_box(self) -> tuple:
        """
        returns bounding box (pmin, pmax)

        :type: tuple
        """
    @property
    def center(self) -> gp_Pnt:
        """
        returns center of gravity of shape

        :type: gp_Pnt
        """
    @property
    def col(self) -> list[float]:
        """
        color of shape as RGB - tuple

        :type: list[float]
        """
    @col.setter
    def col(self, arg1: list[float]) -> None:
        """
        color of shape as RGB - tuple
        """
    @property
    def edges(self) -> netgen::ListOfShapes:
        """
        returns all sub-shapes of type 'EDGE'

        :type: netgen::ListOfShapes
        """
    @property
    def faces(self) -> netgen::ListOfShapes:
        """
        returns all sub-shapes of type 'FACE'

        :type: netgen::ListOfShapes
        """
    @property
    def hpref(self) -> float:
        """
        number of refinement levels for geometric refinement

        :type: float
        """
    @hpref.setter
    def hpref(self, arg1: float) -> None:
        """
        number of refinement levels for geometric refinement
        """
    @property
    def location(self) -> TopLoc_Location:
        """
        Location of shape

        :type: TopLoc_Location
        """
    @location.setter
    def location(self, arg1: TopLoc_Location) -> None:
        """
        Location of shape
        """
    @property
    def mass(self) -> float:
        """
        returns mass of shape, what is length, face, or volume

        :type: float
        """
    @property
    def maxh(self) -> float:
        """
        maximal mesh-size for shape

        :type: float
        """
    @maxh.setter
    def maxh(self, arg1: float) -> None:
        """
        maximal mesh-size for shape
        """
    @property
    def name(self) -> typing.Optional[str]:
        """
        'name' of shape

        :type: typing.Optional[str]
        """
    @name.setter
    def name(self, arg1: typing.Optional[str]) -> None:
        """
        'name' of shape
        """
    @property
    def solids(self) -> netgen::ListOfShapes:
        """
        returns all sub-shapes of type 'SOLID'

        :type: netgen::ListOfShapes
        """
    @property
    def type(self) -> TopAbs_ShapeEnum:
        """
        returns type of shape, i.e. 'EDGE', 'FACE', ...

        :type: TopAbs_ShapeEnum
        """
    @property
    def vertices(self) -> netgen::ListOfShapes:
        """
        returns all sub-shapes of type 'VERTEX'

        :type: netgen::ListOfShapes
        """
    @property
    def wires(self) -> netgen::ListOfShapes:
        """
        returns all sub-shapes of type 'WIRE'

        :type: netgen::ListOfShapes
        """
    pass
class DirectionalInterval():
    def __and__(self, arg0: DirectionalInterval) -> DirectionalInterval: ...
    def __gt__(self, arg0: float) -> DirectionalInterval: ...
    def __lt__(self, arg0: float) -> DirectionalInterval: ...
    def __str__(self) -> str: ...
    pass
class Edge(TopoDS_Shape):
    @staticmethod
    def Split(*args, **kwargs) -> typing.Any: 
        """
        Splits edge at given parameters. Parameters can either be floating values in (0,1), then edge parametrization is used. Or it can be points, then the projection of these points are used for splitting the edge.
        """
    def Tangent(self, s: float) -> gp_Vec: 
        """
        tangent vector to curve at parameter 's'
        """
    def Value(self, s: float) -> gp_Pnt: 
        """
        evaluate curve for parameters 's'
        """
    @staticmethod
    @typing.overload
    def __init__(*args, **kwargs) -> typing.Any: ...
    @typing.overload
    def __init__(self, arg0: TopoDS_Shape) -> None: ...
    @property
    def end(self) -> gp_Pnt:
        """
        end-point of curve

        :type: gp_Pnt
        """
    @property
    def end_tangent(self) -> gp_Vec:
        """
        tangent at end-point

        :type: gp_Vec
        """
    @property
    def parameter_interval(self) -> tuple[float, float]:
        """
        parameter interval of curve

        :type: tuple[float, float]
        """
    @property
    def start(self) -> gp_Pnt:
        """
        start-point of curve

        :type: gp_Pnt
        """
    @property
    def start_tangent(self) -> gp_Vec:
        """
        tangent at start-point

        :type: gp_Vec
        """
    pass
class Face(TopoDS_Shape):
    def ProjectWire(self, arg0: Wire) -> TopoDS_Shape: ...
    def WorkPlane(self) -> WorkPlane: ...
    @typing.overload
    def __init__(self, arg0: TopoDS_Shape) -> None: ...
    @typing.overload
    def __init__(self, f: Face, w: Wire) -> None: ...
    @typing.overload
    def __init__(self, f: Face, w: list[Wire]) -> None: ...
    @typing.overload
    def __init__(self, w: Wire) -> None: ...
    @property
    def quad_dominated(self) -> typing.Optional[bool]:
        """
        :type: typing.Optional[bool]
        """
    @quad_dominated.setter
    def quad_dominated(self, arg1: typing.Optional[bool]) -> None:
        pass
    @property
    def surf(self) -> opencascade::handle<Geom_Surface>:
        """
        :type: opencascade::handle<Geom_Surface>
        """
    pass
class Geom2d_Curve():
    def Edge(self) -> Edge: ...
    def Face(self) -> Face: ...
    def Trim(self, arg0: float, arg1: float) -> Geom2d_Curve: ...
    def Value(self, arg0: float) -> gp_Pnt2d: ...
    def Wire(self) -> Wire: ...
    @property
    def end(self) -> gp_Pnt2d:
        """
        :type: gp_Pnt2d
        """
    @property
    def start(self) -> gp_Pnt2d:
        """
        :type: gp_Pnt2d
        """
    pass
class Geom_Surface():
    def D1(self, arg0: float, arg1: float) -> tuple[gp_Pnt, gp_Vec, gp_Vec]: ...
    def Normal(self, arg0: float, arg1: float) -> gp_Dir: ...
    def Value(self, arg0: float, arg1: float) -> gp_Pnt: ...
    pass
class ListOfShapes():
    @staticmethod
    def Identify(*args, **kwargs) -> typing.Any: 
        """
        Identify shapes for periodic meshing
        """
    def Max(self, dir: gp_Vec) -> object: 
        """
        returns shape where center of gravity is maximal in the direction 'dir'
        """
    def Min(self, dir: gp_Vec) -> object: 
        """
        returns shape where center of gravity is minimal in the direction 'dir'
        """
    @typing.overload
    def Nearest(self, p: gp_Pnt) -> object: 
        """
        returns shape nearest to point 'p'

        returns shape nearest to point 'p'
        """
    @typing.overload
    def Nearest(self, p: gp_Pnt2d) -> object: ...
    def Sorted(self, dir: gp_Vec) -> ListOfShapes: 
        """
        returns list of shapes, where center of gravity is sorted in direction of 'dir'
        """
    @typing.overload
    def __add__(self, arg0: ListOfShapes) -> ListOfShapes: ...
    @typing.overload
    def __add__(self, arg0: list) -> ListOfShapes: ...
    @typing.overload
    def __getitem__(self, arg0: DirectionalInterval) -> ListOfShapes: 
        """
        returns list of all shapes named 'name'
        """
    @typing.overload
    def __getitem__(self, arg0: int) -> object: ...
    @typing.overload
    def __getitem__(self, arg0: slice) -> ListOfShapes: ...
    @typing.overload
    def __getitem__(self, arg0: str) -> ListOfShapes: ...
    def __init__(self, arg0: list[TopoDS_Shape]) -> None: ...
    def __iter__(self) -> typing.Iterator[object]: ...
    def __len__(self) -> int: ...
    def __mul__(self, arg0: ListOfShapes) -> ListOfShapes: ...
    @property
    def col(self) -> None:
        """
        set col for all elements of list

        :type: None
        """
    @col.setter
    def col(self, arg1: list[float]) -> None:
        """
        set col for all elements of list
        """
    @property
    def edges(self) -> ListOfShapes:
        """
        :type: ListOfShapes
        """
    @property
    def faces(self) -> ListOfShapes:
        """
        :type: ListOfShapes
        """
    @property
    def hpref(self) -> None:
        """
        set hpref for all elements of list

        :type: None
        """
    @hpref.setter
    def hpref(self, arg1: float) -> None:
        """
        set hpref for all elements of list
        """
    @property
    def maxh(self) -> None:
        """
        set maxh for all elements of list

        :type: None
        """
    @maxh.setter
    def maxh(self, arg1: float) -> None:
        """
        set maxh for all elements of list
        """
    @property
    def name(self) -> None:
        """
        set name for all elements of list

        :type: None
        """
    @name.setter
    def name(self, arg1: typing.Optional[str]) -> None:
        """
        set name for all elements of list
        """
    @property
    def quad_dominated(self) -> None:
        """
        :type: None
        """
    @quad_dominated.setter
    def quad_dominated(self, arg1: typing.Optional[bool]) -> None:
        pass
    @property
    def solids(self) -> ListOfShapes:
        """
        :type: ListOfShapes
        """
    @property
    def vertices(self) -> ListOfShapes:
        """
        :type: ListOfShapes
        """
    @property
    def wires(self) -> ListOfShapes:
        """
        :type: ListOfShapes
        """
    pass
class OCCException(Exception, BaseException):
    pass
class OCCGeometry(netgen.libngpy._meshing.NetgenGeometry):
    """
    Use LoadOCCGeometry to load the geometry from a *.step file.
    """
    def Draw(self) -> None: ...
    def GenerateMesh(self, mp: netgen.libngpy._meshing.MeshingParameters = None, comm: netgen.libngpy._meshing.MPI_Comm = ..., mesh: netgen.libngpy._meshing.Mesh = None, **kwargs) -> netgen.libngpy._meshing.Mesh: 
        """
        Meshing Parameters
        -------------------

        maxh: float = 1e10
          Global upper bound for mesh size.

        grading: float = 0.3
          Mesh grading how fast the local mesh size can change.

        meshsizefilename: str = None
          Load meshsize from file. Can set local mesh size for points
          and along edges. File must have the format:

            nr_points
            x1, y1, z1, meshsize
            x2, y2, z2, meshsize
            ...
            xn, yn, zn, meshsize

            nr_edges
            x11, y11, z11, x12, y12, z12, meshsize
            ...
            xn1, yn1, zn1, xn2, yn2, zn2, meshsize

        segmentsperedge: float = 1.
          Minimal number of segments per edge.

        quad_dominated: bool = False
          Quad-dominated surface meshing.

        blockfill: bool = True
          Do fast blockfilling.

        filldist: float = 0.1
          Block fill up to distance

        delaunay: bool = True
          Use delaunay meshing.

        delaunay2d : bool = True
          Use delaunay meshing for 2d geometries.

        Optimization Parameters
        -----------------------

        optimize3d: str = "cmdmustm"
          3d optimization strategy:
            m .. move nodes
            M .. move nodes, cheap functional
            s .. swap faces
            c .. combine elements
            d .. divide elements
            p .. plot, no pause
            P .. plot, Pause
            h .. Histogramm, no pause
            H .. Histogramm, pause

        optsteps3d: int = 3
          Number of 3d optimization steps.

        optimize2d: str = "smcmSmcmSmcm"
          2d optimization strategy:
            s .. swap, opt 6 lines/node
            S .. swap, optimal elements
            m .. move nodes
            p .. plot, no pause
            P .. plot, pause
            c .. combine

        optsteps2d: int = 3
          Number of 2d optimization steps.

        elsizeweight: float = 0.2
          Weight of element size w.r.t. element shape in optimization.


        OCC Specific Meshing Parameters
        -------------------------------

        closeedgefac: Optional[float] = 2.
          Factor for meshing close edges, if None it is disabled.

        minedgelen: Optional[float] = 0.001
          Minimum edge length to be used for dividing edges to mesh points. If
          None this is disabled.
        """
    def Glue(self) -> None: ...
    def Heal(self, tolerance: float = 0.001, fixsmalledges: bool = True, fixspotstripfaces: bool = True, sewfaces: bool = True, makesolids: bool = True, splitpartitions: bool = False) -> None: 
        """
        Heal the OCCGeometry.
        """
    def SetFaceMeshsize(self, arg0: int, arg1: float) -> None: 
        """
        Set maximum meshsize for face fnr. Face numbers are 0 based.
        """
    def __getstate__(self) -> tuple: ...
    @typing.overload
    def __init__(self, filename: str, dim: int = 3) -> None: 
        """
        Create Netgen OCCGeometry from existing TopoDS_Shape

        Create Netgen OCCGeometry from existing TopoDS_Shape

        Load OCC geometry from step, brep or iges file
        """
    @typing.overload
    def __init__(self, shape: TopoDS_Shape, dim: int = 3, copy: bool = False) -> None: ...
    @typing.overload
    def __init__(self, shape: list[TopoDS_Shape]) -> None: ...
    def __setstate__(self, arg0: tuple) -> None: ...
    def _visualizationData(self) -> dict: ...
    @property
    def shape(self) -> TopoDS_Shape:
        """
        :type: TopoDS_Shape
        """
    pass
class ShapeContinuity():
    """
    Wrapper for OCC enum GeomAbs_Shape

    Members:

      C0

      C1

      C2

      C3

      CN

      G1

      G2
    """
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self, value: int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self, state: int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> str:
        """
        :type: str
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    C0: netgen.libngpy._NgOCC.ShapeContinuity # value = <ShapeContinuity.C0: 0>
    C1: netgen.libngpy._NgOCC.ShapeContinuity # value = <ShapeContinuity.C1: 2>
    C2: netgen.libngpy._NgOCC.ShapeContinuity # value = <ShapeContinuity.C2: 4>
    C3: netgen.libngpy._NgOCC.ShapeContinuity # value = <ShapeContinuity.C3: 5>
    CN: netgen.libngpy._NgOCC.ShapeContinuity # value = <ShapeContinuity.CN: 6>
    G1: netgen.libngpy._NgOCC.ShapeContinuity # value = <ShapeContinuity.G1: 1>
    G2: netgen.libngpy._NgOCC.ShapeContinuity # value = <ShapeContinuity.G2: 3>
    __members__: dict # value = {'C0': <ShapeContinuity.C0: 0>, 'C1': <ShapeContinuity.C1: 2>, 'C2': <ShapeContinuity.C2: 4>, 'C3': <ShapeContinuity.C3: 5>, 'CN': <ShapeContinuity.CN: 6>, 'G1': <ShapeContinuity.G1: 1>, 'G2': <ShapeContinuity.G2: 3>}
    pass
class Solid(TopoDS_Shape):
    def __init__(self, arg0: TopoDS_Shape) -> None: 
        """
        Create solid from shell. Shell must consist of topologically closed faces (share vertices and edges).
        """
    pass
class TopAbs_ShapeEnum():
    """
    Enumeration of all supported TopoDS_Shapes

    Members:

      COMPOUND

      COMPSOLID

      SOLID

      SHELL

      FACE

      WIRE

      EDGE

      VERTEX

      SHAPE
    """
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self, value: int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self, state: int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> str:
        """
        :type: str
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    COMPOUND: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.COMPOUND: 0>
    COMPSOLID: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.COMPSOLID: 1>
    EDGE: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.EDGE: 6>
    FACE: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.FACE: 4>
    SHAPE: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.SHAPE: 8>
    SHELL: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.SHELL: 3>
    SOLID: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.SOLID: 2>
    VERTEX: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.VERTEX: 7>
    WIRE: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.WIRE: 5>
    __members__: dict # value = {'COMPOUND': <TopAbs_ShapeEnum.COMPOUND: 0>, 'COMPSOLID': <TopAbs_ShapeEnum.COMPSOLID: 1>, 'SOLID': <TopAbs_ShapeEnum.SOLID: 2>, 'SHELL': <TopAbs_ShapeEnum.SHELL: 3>, 'FACE': <TopAbs_ShapeEnum.FACE: 4>, 'WIRE': <TopAbs_ShapeEnum.WIRE: 5>, 'EDGE': <TopAbs_ShapeEnum.EDGE: 6>, 'VERTEX': <TopAbs_ShapeEnum.VERTEX: 7>, 'SHAPE': <TopAbs_ShapeEnum.SHAPE: 8>}
    pass
class TopLoc_Location():
    def Transformation(self) -> gp_Trsf: ...
    def __init__(self, arg0: gp_Trsf) -> None: ...
    pass
class Compound(TopoDS_Shape):
    def __init__(self, shapes: list[TopoDS_Shape], separate_layers: bool = False) -> None: ...
    pass
class Vertex(TopoDS_Shape):
    @typing.overload
    def __init__(self, arg0: TopoDS_Shape) -> None: ...
    @typing.overload
    def __init__(self, arg0: gp_Pnt) -> None: ...
    @property
    def p(self) -> gp_Pnt:
        """
        coordinates of vertex

        :type: gp_Pnt
        """
    pass
class Wire(TopoDS_Shape):
    @typing.overload
    def __init__(self, arg0: Edge) -> None: ...
    @typing.overload
    def __init__(self, arg0: list[TopoDS_Shape]) -> None: ...
    pass
class WorkPlane():
    def Arc(self, r: float, ang: float) -> WorkPlane: 
        """
        draw arc tangential to current pos/dir, of radius 'r' and angle 'ang', draw to the left/right if ang is positive/negative
        """
    def ArcTo(self, arg0: float, arg1: float, arg2: gp_Vec2d) -> WorkPlane: ...
    @typing.overload
    def Circle(self, h: float, v: float, r: float) -> WorkPlane: 
        """
        draw circle with center (h,v) and radius 'r'

        draw circle with center in current position
        """
    @typing.overload
    def Circle(self, r: float) -> WorkPlane: ...
    def Close(self) -> WorkPlane: 
        """
        draw line to start point of wire, and finish wire
        """
    def Direction(self, dirh: float, dirv: float) -> WorkPlane: 
        """
        reset direction to (dirh, dirv)
        """
    def Face(self) -> Face: 
        """
        generate and return face of all wires, resets list of wires
        """
    def Finish(self) -> WorkPlane: 
        """
        finish current wire without closing
        """
    def Last(self) -> typing.Optional[Wire]: 
        """
        (deprecated) returns current wire
        """
    @typing.overload
    def Line(self, dx: float, dy: float, name: typing.Optional[str] = None) -> WorkPlane: ...
    @typing.overload
    def Line(self, l: float, name: typing.Optional[str] = None) -> WorkPlane: ...
    def LineTo(self, h: float, v: float, name: typing.Optional[str] = None) -> WorkPlane: 
        """
        draw line to position (h,v)
        """
    def Move(self, l: float) -> WorkPlane: 
        """
        move 'l' from current position and direction, start new wire
        """
    def MoveTo(self, h: float, v: float) -> WorkPlane: ...
    def NameVertex(self, name: str) -> WorkPlane: 
        """
        name vertex at current position
        """
    def Offset(self, d: float) -> WorkPlane: 
        """
        replace current wire by offset curve of distance 'd'
        """
    def Rectangle(self, l: float, w: float) -> WorkPlane: 
        """
        draw rectangle, with current position as corner, use current direction
        """
    def RectangleC(self, l: float, w: float) -> WorkPlane: 
        """
        draw rectangle, with current position as center, use current direction
        """
    def Reverse(self) -> WorkPlane: 
        """
        revert orientation of current wire
        """
    def Rotate(self, ang: float) -> WorkPlane: 
        """
        rotate current direction by 'ang' degrees
        """
    def Spline(self, points: list[gp_Pnt2d], periodic: bool = False, tol: float = 1e-08, tangents: dict[int, gp_Vec2d] = {}, start_from_localpos: bool = True) -> WorkPlane: 
        """
        draw spline (default: starting from current position, which is implicitly added to given list of points), tangents can be specified for each point (0 refers to starting point)
        """
    def Wire(self) -> typing.Optional[Wire]: 
        """
        returns current wire
        """
    def Wires(self) -> ListOfShapes: 
        """
        returns all wires
        """
    def __init__(self, axes: Axes = ..., pos: gp_Ax2d = ...) -> None: ...
    @property
    def cur_dir(self) -> gp_Vec2d:
        """
        :type: gp_Vec2d
        """
    @property
    def cur_loc(self) -> gp_Pnt2d:
        """
        :type: gp_Pnt2d
        """
    @property
    def start_pnt(self) -> gp_Pnt2d:
        """
        :type: gp_Pnt2d
        """
    pass
class gp_Ax2():
    @typing.overload
    def __init__(self, arg0: gp_Ax3) -> None: ...
    @typing.overload
    def __init__(self, arg0: gp_Pnt, arg1: gp_Dir) -> None: ...
    pass
class gp_Ax2d():
    """
    2d OCC coordinate system
    """
    def __init__(self, p: gp_Pnt2d = (0, 0), d: gp_Dir2d = ...) -> None: ...
    pass
class gp_Dir():
    """
    3d OCC direction
    """
    @typing.overload
    def __init__(self, arg0: gp_Vec) -> None: ...
    @typing.overload
    def __init__(self, arg0: tuple) -> None: ...
    @typing.overload
    def __init__(self, x: float, y: float, z: float) -> None: ...
    def __str__(self) -> str: ...
    pass
class gp_Dir2d():
    """
    2d OCC direction
    """
    @typing.overload
    def __init__(self, arg0: tuple) -> None: ...
    @typing.overload
    def __init__(self, x: float, y: float) -> None: ...
    pass
class gp_GTrsf():
    def __call__(self, arg0: TopoDS_Shape) -> TopoDS_Shape: ...
    def __init__(self, mat: list[float], vec: list[float] = [0.0, 0.0, 0.0]) -> None: ...
    pass
class gp_Pnt():
    """
    3d OCC point
    """
    def __add__(self, arg0: gp_Vec) -> gp_Pnt: ...
    def __getitem__(self, arg0: int) -> float: ...
    @typing.overload
    def __init__(self, arg0: tuple) -> None: ...
    @typing.overload
    def __init__(self, x: float, y: float, z: float) -> None: ...
    def __repr__(self) -> str: ...
    def __str__(self) -> str: ...
    @typing.overload
    def __sub__(self, arg0: gp_Pnt) -> gp_Vec: ...
    @typing.overload
    def __sub__(self, arg0: gp_Vec) -> gp_Pnt: ...
    @property
    def x(self) -> float:
        """
        :type: float
        """
    @x.setter
    def x(self, arg1: float) -> None:
        pass
    @property
    def y(self) -> float:
        """
        :type: float
        """
    @y.setter
    def y(self, arg1: float) -> None:
        pass
    @property
    def z(self) -> float:
        """
        :type: float
        """
    @z.setter
    def z(self, arg1: float) -> None:
        pass
    pass
class gp_Pnt2d():
    """
    2d OCC point
    """
    def __add__(self, arg0: gp_Vec2d) -> gp_Pnt2d: ...
    @typing.overload
    def __init__(self, arg0: tuple) -> None: ...
    @typing.overload
    def __init__(self, x: float, y: float) -> None: ...
    def __repr__(self) -> str: ...
    def __str__(self) -> str: ...
    @typing.overload
    def __sub__(self, arg0: gp_Pnt2d) -> gp_Vec2d: ...
    @typing.overload
    def __sub__(self, arg0: gp_Vec2d) -> gp_Pnt2d: ...
    @property
    def x(self) -> float:
        """
        :type: float
        """
    @x.setter
    def x(self, arg1: float) -> None:
        pass
    @property
    def y(self) -> float:
        """
        :type: float
        """
    @y.setter
    def y(self, arg1: float) -> None:
        pass
    pass
class gp_Trsf():
    def Inverted(self) -> gp_Trsf: ...
    @staticmethod
    def Mirror(arg0: Axis) -> gp_Trsf: ...
    @staticmethod
    @typing.overload
    def Rotation(arg0: Axis, arg1: float) -> gp_Trsf: ...
    @staticmethod
    @typing.overload
    def Rotation(arg0: gp_Pnt, arg1: gp_Dir, arg2: float) -> gp_Trsf: ...
    @staticmethod
    def Scale(arg0: gp_Pnt, arg1: float) -> gp_Trsf: ...
    def SetMirror(self, arg0: Axis) -> gp_Trsf: ...
    @staticmethod
    @typing.overload
    def Transformation(arg0: Axes) -> gp_Trsf: ...
    @staticmethod
    @typing.overload
    def Transformation(arg0: Axes, arg1: Axes) -> gp_Trsf: ...
    @staticmethod
    def Translation(arg0: gp_Vec) -> gp_Trsf: ...
    def __call__(self, arg0: TopoDS_Shape) -> TopoDS_Shape: ...
    def __init__(self) -> None: ...
    def __mul__(self, arg0: gp_Trsf) -> gp_Trsf: ...
    def __str__(self) -> str: ...
    pass
class gp_Vec():
    """
    3d OCC vector
    """
    def Norm(self) -> float: ...
    def __add__(self, arg0: gp_Vec) -> gp_Vec: ...
    @staticmethod
    def __ge__(*args, **kwargs) -> typing.Any: ...
    @staticmethod
    def __gt__(*args, **kwargs) -> typing.Any: ...
    @typing.overload
    def __init__(self, arg0: tuple) -> None: ...
    @typing.overload
    def __init__(self, x: float, y: float, z: float) -> None: ...
    @staticmethod
    def __le__(*args, **kwargs) -> typing.Any: ...
    @staticmethod
    def __lt__(*args, **kwargs) -> typing.Any: ...
    def __mul__(self, arg0: gp_Vec) -> float: ...
    def __neg__(self) -> gp_Vec: ...
    def __repr__(self) -> str: ...
    def __rmul__(self, arg0: float) -> gp_Vec: ...
    def __str__(self) -> str: ...
    def __sub__(self, arg0: gp_Vec) -> gp_Vec: ...
    def __xor__(self, arg0: gp_Vec) -> gp_Vec: ...
    @property
    def x(self) -> float:
        """
        :type: float
        """
    @x.setter
    def x(self, arg1: float) -> None:
        pass
    @property
    def y(self) -> float:
        """
        :type: float
        """
    @y.setter
    def y(self, arg1: float) -> None:
        pass
    @property
    def z(self) -> float:
        """
        :type: float
        """
    @z.setter
    def z(self, arg1: float) -> None:
        pass
    pass
class gp_Vec2d():
    """
    2d OCC vector
    """
    def __add__(self, arg0: gp_Vec2d) -> gp_Vec2d: ...
    @typing.overload
    def __init__(self, arg0: tuple) -> None: ...
    @typing.overload
    def __init__(self, x: float, y: float) -> None: ...
    def __neg__(self) -> gp_Vec2d: ...
    def __repr__(self) -> str: ...
    def __rmul__(self, arg0: float) -> gp_Vec2d: ...
    def __str__(self) -> str: ...
    def __sub__(self, arg0: gp_Vec2d) -> gp_Vec2d: ...
    def __xor__(self, arg0: gp_Vec2d) -> float: ...
    @property
    def x(self) -> float:
        """
        :type: float
        """
    @x.setter
    def x(self, arg1: float) -> None:
        pass
    @property
    def y(self) -> float:
        """
        :type: float
        """
    @y.setter
    def y(self, arg1: float) -> None:
        pass
    pass
@typing.overload
def ArcOfCircle(p1: gp_Pnt, p2: gp_Pnt, p3: gp_Pnt) -> Edge:
    """
    create arc from p1 through p2 to p3

    create arc from p1, with tangent vector v, to point p2
    """
@typing.overload
def ArcOfCircle(p1: gp_Pnt, v: gp_Vec, p2: gp_Pnt) -> Edge:
    pass
def BSplineCurve(arg0: list[gp_Pnt], arg1: int) -> Edge:
    pass
def BezierCurve(points: list[gp_Pnt]) -> Edge:
    """
    create Bezier curve
    """
def Box(p1: gp_Pnt, p2: gp_Pnt) -> Solid:
    """
    create box with opposite points 'p1' and 'p2'
    """
@typing.overload
def Circle(arg0: gp_Pnt, arg1: gp_Dir, arg2: float) -> Edge:
    """
    create 2d circle curve
    """
@typing.overload
def Circle(c: gp_Pnt2d, r: float) -> Geom2d_Curve:
    pass
def Cone(axis: gp_Ax2, r1: float, r2: float, h: float, angle: float) -> Solid:
    """
    create cone given by axis, radius at bottom (z=0) r1, radius at top (z=h) r2, height and angle
    """
def ConnectEdgesToWires(edges: list[TopoDS_Shape], tol: float = 1e-08, shared: bool = True) -> list[Wire]:
    pass
@typing.overload
def Cylinder(axis: gp_Ax2, r: float, h: float) -> Solid:
    """
    create cylinder with base point 'p', axis direction 'd', radius 'r', and height 'h'

    create cylinder given by axis, radius and height
    """
@typing.overload
def Cylinder(p: gp_Pnt, d: gp_Dir, r: float, h: float, bottom: typing.Optional[str] = None, top: typing.Optional[str] = None, mantle: typing.Optional[str] = None) -> object:
    pass
@typing.overload
def Dir(d: list[float]) -> object:
    """
    create 2d OCC direction

    create 3d OCC direction

    create 2d or 3d OCC direction
    """
@typing.overload
def Dir(x: float, y: float) -> gp_Dir2d:
    pass
@typing.overload
def Dir(x: float, y: float, z: float) -> gp_Dir:
    pass
def Ellipse(axes: gp_Ax2d, major: float, minor: float) -> Geom2d_Curve:
    """
    create 2d ellipse curve
    """
def Fuse(arg0: list[TopoDS_Shape]) -> TopoDS_Shape:
    pass
@typing.overload
def Glue(shape: TopoDS_Shape) -> TopoDS_Shape:
    """
    glue together shapes of list

    glue together shapes from shape, typically a compound
    """
@typing.overload
def Glue(shapes: list[TopoDS_Shape]) -> TopoDS_Shape:
    pass
def HalfSpace(p: gp_Pnt, n: gp_Vec) -> TopoDS_Shape:
    """
    Create a half space threw point p normal to n
    """
def LoadOCCGeometry(arg0: os.PathLike) -> netgen.libngpy._meshing.NetgenGeometry:
    pass
def MakeFillet(arg0: TopoDS_Shape, arg1: list[TopoDS_Shape], arg2: float) -> TopoDS_Shape:
    """
    deprecated, use 'shape.MakeFillet'
    """
def MakeThickSolid(arg0: TopoDS_Shape, arg1: list[TopoDS_Shape], arg2: float, arg3: float) -> TopoDS_Shape:
    """
    deprecated, use 'shape.MakeThickSolid'
    """
def Pipe(spine: Wire, profile: TopoDS_Shape, twist: typing.Optional[tuple[gp_Pnt, float]] = None, auxspine: typing.Optional[Wire] = None) -> TopoDS_Shape:
    pass
def PipeShell(spine: Wire, profile: TopoDS_Shape, auxspine: Wire) -> TopoDS_Shape:
    pass
@typing.overload
def Pnt(p: list[float]) -> object:
    """
    create 2d OCC point

    create 3d OCC point

    create 2d or 3d OCC point
    """
@typing.overload
def Pnt(x: float, y: float) -> gp_Pnt2d:
    pass
@typing.overload
def Pnt(x: float, y: float, z: float) -> gp_Pnt:
    pass
def Prism(face: TopoDS_Shape, v: gp_Vec) -> TopoDS_Shape:
    """
    extrude face along the vector 'v'
    """
def Revolve(arg0: TopoDS_Shape, arg1: Axis, arg2: float) -> TopoDS_Shape:
    pass
@typing.overload
def Segment(arg0: gp_Pnt, arg1: gp_Pnt) -> Edge:
    """
    create 2d line curve
    """
@typing.overload
def Segment(p1: gp_Pnt2d, p2: gp_Pnt2d) -> Geom2d_Curve:
    pass
def Sphere(c: gp_Pnt, r: float) -> Solid:
    """
    create sphere with center 'c' and radius 'r'
    """
@typing.overload
def SplineApproximation(points: list[gp_Pnt2d], approx_type: ApproxParamType = ApproxParamType.ChordLength, deg_min: int = 3, deg_max: int = 8, continuity: ShapeContinuity = ShapeContinuity.C2, tol: float = 1e-08) -> Geom2d_Curve:
    """
    Generate a piecewise continuous spline-curve approximating a list of points in 2d.

    Parameters
    ----------

    points : List|Tuple[gp_Pnt2d]
      List (or tuple) of gp_Pnt.

    approx_type : ApproxParamType
      Assumption on location of parameters wrt points.

    deg_min : int
      Minimum polynomial degree of splines

    deg_max : int
      Maximum polynomial degree of splines

    continuity : ShapeContinuity
      Continuity requirement on the approximating surface

    tol : float
      Tolerance for the distance from individual points to the approximating curve.




    Generate a piecewise continuous spline-curve approximating a list of points in 3d.

    Parameters
    ----------

    points : List[gp_Pnt] or Tuple[gp_Pnt]
      List (or tuple) of gp_Pnt.

    approx_type : ApproxParamType
      Assumption on location of parameters wrt points.

    deg_min : int
      Minimum polynomial degree of splines

    deg_max : int
      Maximum polynomial degree of splines

    continuity : ShapeContinuity
      Continuity requirement on the approximating surface

    tol : float
      Tolerance for the distance from individual points to the approximating curve.
    """
@typing.overload
def SplineApproximation(points: list[gp_Pnt], approx_type: ApproxParamType = ApproxParamType.ChordLength, deg_min: int = 3, deg_max: int = 8, continuity: ShapeContinuity = ShapeContinuity.C2, tol: float = 1e-08) -> Edge:
    pass
@typing.overload
def SplineInterpolation(points: list[gp_Pnt2d], periodic: bool = False, tol: float = 1e-08, tangents: dict[int, gp_Vec2d] = {}) -> Geom2d_Curve:
    """
    Generate a piecewise continuous spline-curve interpolating a list of points in 2d.

    Parameters
    ----------

    points : List|Tuple[gp_Pnt2d]
      List (or tuple) of gp_Pnt2d.

    periodic : bool
      Whether the result should be periodic

    tol : float
      Tolerance for the distance between points.

    tangents : Dict[int, gp_Vec2d]
      Tangent vectors for the points indicated by the key value (0-based).




    Generate a piecewise continuous spline-curve interpolating a list of points in 3d.

    Parameters
    ----------

    points : List|Tuple[gp_Pnt]
      List (or tuple) of gp_Pnt

    periodic : bool
      Whether the result should be periodic

    tol : float
      Tolerance for the distance between points.

    tangents : Dict[int, gp_Vec]
      Tangent vectors for the points indicated by the key value (0-based).
    """
@typing.overload
def SplineInterpolation(points: list[gp_Pnt], periodic: bool = False, tol: float = 1e-08, tangents: dict[int, gp_Vec] = {}) -> Edge:
    pass
def SplineSurfaceApproximation(points: numpy.ndarray[numpy.float64], approx_type: ApproxParamType = ApproxParamType.ChordLength, deg_min: int = 3, deg_max: int = 8, continuity: ShapeContinuity = ShapeContinuity.C2, tol: float = 0.001, periodic: bool = False, degen_tol: float = 1e-08) -> Face:
    """
    Generate a piecewise continuous spline-surface approximating an array of points.

    Parameters
    ----------

    points : np.ndarray
      Array of points coordinates. The first dimension corresponds to the first surface coordinate point
      index, the second dimension to the second surface coordinate point index. The third dimension refers to physical
      coordinates. Such an array can be generated with code like::

          px, py = np.meshgrid(*[np.linspace(0, 1, N)]*2)
          points = np.array([[(px[i,j], py[i,j], px[i,j]*py[i,j]**2) for j in range(N)] for i in range(N)])

    approx_type : ApproxParamType
      Assumption on location of parameters wrt points.

    deg_min : int
      Minimum polynomial degree of splines

    deg_max : int
      Maximum polynomial degree of splines

    continuity : ShapeContinuity
      Continuity requirement on the approximating surface

    tol : float
      Tolerance for the distance from individual points to the approximating surface.

    periodic : bool
      Whether the result should be periodic in the first surface parameter

    degen_tol : double
      Tolerance for resolution of degenerate edges
    """
def SplineSurfaceInterpolation(points: numpy.ndarray[numpy.float64], approx_type: ApproxParamType = ApproxParamType.ChordLength, periodic: bool = False, degen_tol: float = 1e-08) -> Face:
    """
    Generate a piecewise continuous spline-surface interpolating an array of points.

    Parameters
    ----------

    points : np.ndarray
      Array of points coordinates. The first dimension corresponds to the first surface coordinate point
      index, the second dimension to the second surface coordinate point index. The third dimension refers to physical
      coordinates. Such an array can be generated with code like::

          px, py = np.meshgrid(*[np.linspace(0, 1, N)]*2)
          points = np.array([[(px[i,j], py[i,j], px[i,j]*py[i,j]**2) for j in range(N)] for i in range(N)])

    approx_type : ApproxParamType
      Assumption on location of parameters wrt points.

    periodic : bool
      Whether the result should be periodic in the first surface parameter

    degen_tol : double
      Tolerance for resolution of degenerate edges
    """
def TestXCAF(shape: TopoDS_Shape = ...) -> None:
    pass
def ThruSections(wires: list[TopoDS_Shape], solid: bool = True) -> TopoDS_Shape:
    """
    Building a loft. This is a shell or solid passing through a set of sections (wires). First and last sections may be vertices. See https://dev.opencascade.org/doc/refman/html/class_b_rep_offset_a_p_i___thru_sections.html#details
    """
@typing.overload
def Vec(v: list[float]) -> object:
    """
    create 2d OCC point

    create 3d OCC point

    create 2d or 3d OCC vector
    """
@typing.overload
def Vec(x: float, y: float) -> gp_Vec2d:
    pass
@typing.overload
def Vec(x: float, y: float, z: float) -> gp_Vec:
    pass
COMPOUND: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.COMPOUND: 0>
COMPSOLID: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.COMPSOLID: 1>
EDGE: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.EDGE: 6>
FACE: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.FACE: 4>
SHAPE: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.SHAPE: 8>
SHELL: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.SHELL: 3>
SOLID: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.SOLID: 2>
VERTEX: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.VERTEX: 7>
WIRE: netgen.libngpy._NgOCC.TopAbs_ShapeEnum # value = <TopAbs_ShapeEnum.WIRE: 5>
X: netgen.libngpy._NgOCC.gp_Vec # value = (1, 0, 0)
Y: netgen.libngpy._NgOCC.gp_Vec # value = (0, 1, 0)
Z: netgen.libngpy._NgOCC.gp_Vec # value = (0, 0, 1)
occ_version = '7.7.2'
